tlslite.utils.hmac.HMAC

Package tlslite :: Package utils :: Module hmac :: Class HMAC |
[show private | hide private]
[frames | no frames]

## Class HMAC

RFC2104 HMAC class.

This supports the API for Cryptographic Hash Functions (PEP 247).

Method Summary
| ``__init__`(self, key, msg, digestmod)` Create a new HMAC object.
| ``copy`(self)` Return a separate copy of this hashing object.
| ``digest`(self)` Return the hash value of this hashing object.
| ``hexdigest`(self)` Like digest(), but returns a string of hexadecimal digits instead.
| ``update`(self, msg)` Update this hashing object with the string msg.

Method Details

### __init__(self, key, msg=None, digestmod=None) (Constructor) Create a new HMAC object. key: key for the keyed hash object. msg: Initial input for the hash, if provided. digestmod: A module supporting PEP 247. Defaults to the md5 module.

### copy(self) Return a separate copy of this hashing object. An update to this copy won't affect the original object.

### digest(self) Return the hash value of this hashing object. This returns a string containing 8-bit data. The object is not altered in any way by this function; you can continue updating the object after calling this function.

### hexdigest(self) Like digest(), but returns a string of hexadecimal digits instead.

### update(self, msg) Update this hashing object with the string msg.

Generated by Epydoc 2.0 on Mon Feb 21 21:56:54 2005 | http://epydoc.sf.net